@@ -1,4 +1,16 @@
+// [IGE]: avoid linking to python37_d.lib
+#ifdef _DEBUG
+#  define IGE_DEBUG
+#  undef _DEBUG
+#endif
+
 #include <Python.h>
+
+#ifdef IGE_DEBUG
+# define _DEBUG
+#endif
+// [/IGE]
+
 #include "Firebase.h"
 #include "FirebaseAnalytics.h"
 #include "FirebaseAuth.h"
