@@ -100,13 +100,10 @@ static PyObject* firebaseMLKit_GetCameraSize(firebaseMLKit_obj* self)
 
 static PyObject* firebaseMLKit_GetCameraData(firebaseMLKit_obj* self)
 {
-	uint8_t* result = FirebaseMLKit::Instance()->getCameraData();
-	PyObject* obj = PyBytes_FromStringAndSize((char*)result, FirebaseMLKit::Instance()->getCameraWidth() * FirebaseMLKit::Instance()->getCameraHeight() * 3);
+    uint8_t* result = FirebaseMLKit::Instance()->getCameraData();
+    PyObject* obj = PyBytes_FromStringAndSize((char*)result, FirebaseMLKit::Instance()->getCameraWidth() * FirebaseMLKit::Instance()->getCameraHeight() * 3);
 
-	PyObject* data = Py_BuildValue("(Oii)", obj, FirebaseMLKit::Instance()->getCameraWidth(), FirebaseMLKit::Instance()->getCameraHeight());
-	Py_DECREF(obj);
-
-	return data;
+    return obj;
 }
 
 static PyObject* firebaseMLKit_SetContourList(firebaseMLKit_obj* self, PyObject* args)
@@ -129,6 +126,22 @@ static PyObject* firebaseMLKit_SetContourList(firebaseMLKit_obj* self, PyObject*
 	return Py_None;
 }
 
+static PyObject* firebaseMLKit_getLeftEyeOpenProbability(firebaseMLKit_obj* self)
+{
+	float result = FirebaseMLKit::Instance()->getLeftEyeOpenProbability();
+	PyObject* obj = Py_BuildValue("f", result);
+
+	return obj;
+}
+
+static PyObject* firebaseMLKit_GetRightEyeOpenProbability(firebaseMLKit_obj* self)
+{
+	float result = FirebaseMLKit::Instance()->getRightEyeOpenProbability();
+	PyObject* obj = Py_BuildValue("f", result);
+
+	return obj;
+}
+
 PyMethodDef firebaseMLKit_methods[] = {
 	{ "isSupported", (PyCFunction)firebaseMLKit_isSupported, METH_NOARGS, firebaseMLKitIsSupported_doc },
 	{ "init", (PyCFunction)firebaseMLKit_Init, METH_VARARGS, firebaseMLKitInit_doc },
@@ -136,9 +149,11 @@ PyMethodDef firebaseMLKit_methods[] = {
 	{ "preview", (PyCFunction)firebaseMLKit_Preview, METH_NOARGS, firebaseMLKitPreview_doc },
 	{ "getContours", (PyCFunction)firebaseMLKit_GetContours, METH_NOARGS, firebaseMLKitGetContours_doc },
 	{ "getHeadEulerAngle", (PyCFunction)firebaseMLKit_getHeadEulerAngle, METH_NOARGS, firebaseMLKitGetHeadEulerAngle_doc },
-    { "getCameraSize", (PyCFunction)firebaseMLKit_GetCameraSize, METH_NOARGS, cameraGetCameraSize_doc },
-    { "getCameraData", (PyCFunction)firebaseMLKit_GetCameraData, METH_NOARGS, cameraGetCameraData_doc },
+	{ "getCameraSize", (PyCFunction)firebaseMLKit_GetCameraSize, METH_NOARGS, cameraGetCameraSize_doc },
+	{ "getCameraData", (PyCFunction)firebaseMLKit_GetCameraData, METH_NOARGS, cameraGetCameraData_doc },
 	{ "setContourList", (PyCFunction)firebaseMLKit_SetContourList, METH_VARARGS, firebaseMLKitSetContourList_doc },
+	{ "getLeftEyeOpenProbability", (PyCFunction)firebaseMLKit_getLeftEyeOpenProbability, METH_VARARGS, firebaseMLKitGetLeftEyeOpenProbability_doc },
+	{ "getRightEyeOpenProbability", (PyCFunction)firebaseMLKit_GetRightEyeOpenProbability, METH_VARARGS, firebaseMLKitGetRightEyeOpenProbability_doc },
 	{ NULL,	NULL }
 };
 
