@@ -2,8 +2,6 @@
 
 
 FirebaseMLKitImpl::FirebaseMLKitImpl()
-	: contourPoints(nullptr)
-	, rgbData(nullptr)
 {
 }
 
@@ -13,10 +11,6 @@ FirebaseMLKitImpl::~FirebaseMLKitImpl()
 
 void FirebaseMLKitImpl::Init(int mode)
 {
-	if (contourPoints == nullptr)
-	{
-		contourPoints = new float[allContourPointsSize * 2];
-	}
 }
 
 void FirebaseMLKitImpl::Release()
@@ -44,25 +38,25 @@ float* FirebaseMLKitImpl::GetContours(int& size)
 
 uint8_t* FirebaseMLKitImpl::GetCameraData()
 {
-	int h = GetCameraHeight();
-	int w = GetCameraWidth();
-
-	if (rgbData == nullptr)
-	{
-		size_t len = (size_t)w * h * 3;
-		rgbData = new uint8_t[len];
-		memset(rgbData, 0, len);
-	}
-
-	return rgbData;
+	return {};
 }
 
 int FirebaseMLKitImpl::GetCameraWidth()
 {
-	return 360;
+	return 0;
 }
 
 int FirebaseMLKitImpl::GetCameraHeight()
 {
-	return 480;
+	return 0;
+}
+
+float FirebaseMLKitImpl::GetLeftEyeOpenProbability()
+{
+	return 0.f;
+}
+
+float FirebaseMLKitImpl::GetRightEyeOpenProbability()
+{
+	return 0.f;
 }
\ No newline at end of file
